@@ -77,6 +77,8 @@ class Client(object):
             source = CONFIG[self.sender_id]['source']
         except KeyError:
             source = CONFIG['bip']['source']
+        log_source = '<<< source={}'.format(source)
+        journal.send(log_source)
         self.request_id = kwargs['request_id']
         self.infos = {
             'msisdn': msisdn,
